@@ -22,7 +22,7 @@ impl IndexBuilder for PostgresQueryBuilder {
 
         write!(sql, " ON ").unwrap();
         if let Some(table) = &create.table {
-            table.prepare(sql, '"');
+            table.prepare(sql, self.quote());
         }
 
         self.prepare_index_type(&create.index_type, sql);
