@@ -8,7 +8,7 @@
 //!   <h1>SeaQuery</h1>
 //!
 //!   <p>
-//!     <strong>🌊 A dynamic query builder for MySQL, Postgres and SQLite</strong>
+//!     <strong>🔱 A dynamic query builder for MySQL, Postgres and SQLite</strong>
 //!   </p>
 //!
 //!   [![crate](https://img.shields.io/crates/v/sea-query.svg)](https://crates.io/crates/sea-query)
@@ -751,3 +751,5 @@ pub use value::*;
 
 #[cfg(feature = "derive")]
 pub use sea_query_derive::Iden;
+
+pub use sea_query_driver::*;
